**Example 1: 设置实时录制回调地址**



Input: 

```
tccli tiw SetOnlineRecordCallback --cli-unfold-argument  \
    --SdkAppId 1400000001 \
    --Callback https://example.com/online/callback
```

Output: 
```
{
    "Response": {
        "RequestId": "eac6b301-a322-493a-8e36-83b295459397"
    }
}
```

